==> vdr-plugin-rotor_0.1.2.orig.tar.gz: rotor-0.1.2/i18n.c <==
/*
 * i18n.c: Internationalization
 *
 * See the README file for copyright information and how to reach the author.
 * Russian: Vyacheslav Dikonov <sdiconov@mail.ru>
 *
 */

#include "i18n.h"

const tI18nPhrase Phrases[] = {
  { "Drive West",
    "Nach Westen",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Aller Ouest",
    "",// TODO
    "Ohjaa lnteen",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    " ",
  },
  { "Drive East",
    "Nach Osten",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Aller Est",
    "",// TODO
    "Ohjaa itn",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    " ",
  },
  { "Halt",
    "Anhalten",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Arrt",
    "",// TODO
    "Pysyt",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",
  },
  { "Steps",
    "Schritte",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Incrment",
    "",// TODO
    "askelta",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "() ",
  },
  { "Recalc",
    "Recalc",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Recalc",
    "",// TODO
    "Laske uudelleen",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",
  },
  { "Goto",
    "Gehe zu",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Aller ",
    "",// TODO
    "Siirry",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",
  },
  { "Store",
    "Speichere",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Enregistrer",
    "",// TODO
    "Tallenna",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",
  },
  { "Limits off",
    "Limits aus",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Dsactiver Limites",
    "",// TODO
    "Ei rajoituksia",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    " ",
  },
  { "Set East Limit",
    "Ost-Limit",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Limite Est",
    "",// TODO
    "Aseta rajoitus itn",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    " ",
  },
  { "Set West Limit",
    "West-Limit",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Limite Ouest",
    "",// TODO
    "Aseta rajoitus lnteen",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    " ",
  },
  { "Enable Limits",
    "Limits ein",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Activer Limites",
    "",// TODO
    "Kyt rajoituksia",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    " ",
  },
  { "Position",
    "Position",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",
    "",// TODO
    "Sijainti",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",
  },
  { "Card, connected with motor",
    "Karte, die mit Motor verbunden ist ",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Carte, connecte au moteur",
    "",// TODO
    "Moottoriin kytketty DVB-kortti",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "   ",
  },
  { "Repeat DiSEqC-Commands?",
    "DiSEqC-Befehle wiederholen?",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Rpter Commandes DiSEqc?",
    "",// TODO
    "Toista DiSEqC-komennot",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "  DiSEqC?",
  },
  { "Address-Byte",
    "Address-Byte",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Adresse",
    "",// TODO
    "Osoitetavu",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    " ",
  },
  { "Are you sure?",
    "Sind sie sicher?",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Etes vous sur?",
    "",// TODO
    "Oletko varma?",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    " ?",
  },
  { "Not in DISEQC.CONF",
    "Kein Eintrag in DISEQC.CONF",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Pas dans DISEQC.CONF",
    "",// TODO
    "Ei lydy DISEQC.CONF-tiedostosta",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "  diseqc.conf",
  },
  { "Frequency",
    "Frequenz",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Frquence",
    "",// TODO
    "Taajuus",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",
  },
  { "Symbolrate",
    "Symbolrate",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "SymbolRate",
    "",// TODO
    "Symbolinopeus",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    ". ",
  },
  { "Scan Transponder",
    "Scan Transponder",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Scanner Transpondeur",
    "",// TODO
    "Etsi transponderin kanavat",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    " ",
  },
  { "Rotor",
    "Rotor",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Motorisation",
    "",// TODO
    "Moottori",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",
  },
  { "Steuerung eines Rotors",
    "Steuerung eines Rotors",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Moottorin ohjaus",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    " ",
  },
  { "Longitude",
    "Lngengrad",
    "",
    "",
    "",
    "",
    "Longitude",
    "",
    "Pituusaste",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
  },
  { "East",
    "Ost",
    "",
    "",
    "",
    "",
    "Est",
    "",
    "itist",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
  },
  { "To East",
    "Nach Osten",
    "",
    "",
    "",
    "",
    "Est",
    "",
    "Itn",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
  },
  { "West",
    "West",
    "",
    "",
    "",
    "",
    "Ouest",
    "",
    "lntist",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
  },
  { "To West",
    "Nach Westen",
    "",
    "",
    "",
    "",
    "Ouest",
    "",
    "Lnteen",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
  },
  { "Latitude",
    "Breitengrad",
    "",
    "",
    "",
    "",
    "Latitude",
    "",
    "Leveysaste",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
  },
  { "South",
    "Sd",
    "",
    "",
    "",
    "",
    "Sud",
    "",
    "etelist",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
  },
  { "North",
    "Nord",
    "",
    "",
    "",
    "",
    "Nord",
    "",
    "pohjoista",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
  },
  { "Use GotoX on channel switch",
    "GotoX beim Kanalwechesel benutzen",
    "",
    "",
    "",
    "",
    "",
    "",
    "Kyt GotoX-kanavanvaihtoa",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    ". GotoX   ",
  },
  { "Rotating Dish",
    "Schssel dreht sich",
    "",
    "",
    "",
    "",
    "",
    "",
    "Knnetn lautasta",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "  ",
  },
  { "Configure",
    "Konfigurieren",
    "",
    "",
    "",
    "",
    "",
    "",
    "Konfiguroi",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
  },
  { "React to switching of 1.Card",
    "Kanalwechsel 1.Karte bercks.",
    "",
    "",
    "",
    "",
    "",
    "",
    "Reagoi 1. kortin kanavanvaihtoon",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
  },
  { "React to switching of 2.Card",
    "Kanalwechsel 2.Karte bercks.",
    "",
    "",
    "",
    "",
    "",
    "",
    "Reagoi 2. kortin kanavanvaihtoon",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
  },
  { "React to switching of 3.Card",
    "Kanalwechsel 3.Karte bercks.",
    "",
    "",
    "",
    "",
    "",
    "",
    "Reagoi 3. kortin kanavanvaihtoon",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
  },
  { "React to switching of 4.Card",
    "Kanalwechsel 4.Karte bercks.",
    "",
    "",
    "",
    "",
    "",
    "",
    "Reagoi 4. kortin kanavanvaihtoon",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
  },
  { "Add Channel",
    "Add Channel",
    "",
    "",
    "",
    "",
    "",
    "",
    "Lis kanava",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
  },
  { "Add All",
    "Add All",
    "",
    "",
    "",
    "",
    "",
    "",
    "Lis kaikki",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
  },
  { NULL }
  };

==> vdr-plugin-rotor_0.1.4.orig.tar.gz: rotor-0.1.4/i18n.c <==
/*
 * i18n.c: Internationalization
 *
 * See the README file for copyright information and how to reach the author.
 * Russian: Vyacheslav Dikonov <sdiconov@mail.ru>
 *
 */

#include "i18n.h"

const tI18nPhrase Phrases[] = {
  { "Drive West",
    "Nach Westen",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Aller Ouest",
    "",// TODO
    "Ohjaa lnteen",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    " ",
  },
  { "Drive East",
    "Nach Osten",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Aller Est",
    "",// TODO
    "Ohjaa itn",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    " ",
  },
  { "Halt",
    "Anhalten",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Arrt",
    "",// TODO
    "Pysyt",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",
  },
  { "Steps",
    "Schritte",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Incrment",
    "",// TODO
    "askelta",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "() ",
  },
  { "Recalc",
    "Recalc",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Recalc",
    "",// TODO
    "Laske uudelleen",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",
  },
  { "Goto",
    "Gehe zu",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Aller ",
    "",// TODO
    "Siirry",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",
  },
  { "Store",
    "Speichere",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Enregistrer",
    "",// TODO
    "Tallenna",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",
  },
  { "Limits off",
    "Limits aus",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Dsactiver Limites",
    "",// TODO
    "Ei rajoituksia",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    " ",
  },
  { "Set East Limit",
    "Ost-Limit",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Limite Est",
    "",// TODO
    "Aseta rajoitus itn",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    " ",
  },
  { "Set West Limit",
    "West-Limit",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Limite Ouest",
    "",// TODO
    "Aseta rajoitus lnteen",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    " ",
  },
  { "Enable Limits",
    "Limits ein",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Activer Limites",
    "",// TODO
    "Kyt rajoituksia",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    " ",
  },
  { "Position",
    "Position",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",
    "",// TODO
    "Sijainti",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",
  },
  { "Card, connected with motor",
    "Karte, die mit Motor verbunden ist ",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Carte, connecte au moteur",
    "",// TODO
    "Moottoriin kytketty DVB-kortti",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "   ",
  },
  { "Repeat DiSEqC-Commands?",
    "DiSEqC-Befehle wiederholen?",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Rpter Commandes DiSEqc?",
    "",// TODO
    "Toista DiSEqC-komennot",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "  DiSEqC?",
  },
  { "Address-Byte",
    "Address-Byte",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Adresse",
    "",// TODO
    "Osoitetavu",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    " ",
  },
  { "Are you sure?",
    "Sind sie sicher?",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Etes vous sur?",
    "",// TODO
    "Oletko varma?",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    " ?",
  },
  { "Not in DISEQC.CONF",
    "Kein Eintrag in DISEQC.CONF",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Pas dans DISEQC.CONF",
    "",// TODO
    "Ei lydy DISEQC.CONF-tiedostosta",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "  diseqc.conf",
  },
  { "Frequency",
    "Frequenz",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Frquence",
    "",// TODO
    "Taajuus",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",
  },
  { "Symbolrate",
    "Symbolrate",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "SymbolRate",
    "",// TODO
    "Symbolinopeus",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    ". ",
  },
  { "Scan Transponder",
    "Scan Transponder",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Scanner Transpondeur",
    "",// TODO
    "Etsi transponderin kanavat",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    " ",
  },
  { "Rotor",
    "Rotor",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Motorisation",
    "",// TODO
    "Moottori",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",
  },
  { "Steuerung eines Rotors",
    "Steuerung eines Rotors",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Moottorin ohjaus",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    " ",
  },
  { "Longitude",
    "Lngengrad",
    "",
    "",
    "",
    "",
    "Longitude",
    "",
    "Pituusaste",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
  },
  { "East",
    "Ost",
    "",
    "",
    "",
    "",
    "Est",
    "",
    "itist",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
  },
  { "To East",
    "Nach Osten",
    "",
    "",
    "",
    "",
    "Est",
    "",
    "Itn",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
  },
  { "West",
    "West",
    "",
    "",
    "",
    "",
    "Ouest",
    "",
    "lntist",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
  },
  { "To West",
    "Nach Westen",
    "",
    "",
    "",
    "",
    "Ouest",
    "",
    "Lnteen",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
  },
  { "Latitude",
    "Breitengrad",
    "",
    "",
    "",
    "",
    "Latitude",
    "",
    "Leveysaste",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
  },
  { "South",
    "Sd",
    "",
    "",
    "",
    "",
    "Sud",
    "",
    "etelist",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
  },
  { "North",
    "Nord",
    "",
    "",
    "",
    "",
    "Nord",
    "",
    "pohjoista",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
  },
  { "Move on channel switch",
    "Beim Kanalwechsel drehen",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
  },
  { "Rotating Dish",
    "Schssel dreht sich",
    "",
    "",
    "",
    "",
    "",
    "",
    "Knnetn lautasta",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "  ",
  },
  { "Configure",
    "Konfigurieren",
    "",
    "",
    "",
    "",
    "",
    "",
    "Konfiguroi",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
  },
  { "React to switching of 1.Card",
    "Kanalwechsel 1.Karte bercks.",
    "",
    "",
    "",
    "",
    "",
    "",
    "Reagoi 1. kortin kanavanvaihtoon",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
  },
  { "React to switching of 2.Card",
    "Kanalwechsel 2.Karte bercks.",
    "",
    "",
    "",
    "",
    "",
    "",
    "Reagoi 2. kortin kanavanvaihtoon",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
  },
  { "React to switching of 3.Card",
    "Kanalwechsel 3.Karte bercks.",
    "",
    "",
    "",
    "",
    "",
    "",
    "Reagoi 3. kortin kanavanvaihtoon",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
  },
  { "React to switching of 4.Card",
    "Kanalwechsel 4.Karte bercks.",
    "",
    "",
    "",
    "",
    "",
    "",
    "Reagoi 4. kortin kanavanvaihtoon",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
  },
  { "Add Channel",
    "Add Channel",
    "",
    "",
    "",
    "",
    "",
    "",
    "Lis kanava",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
  },
  { "Add All",
    "Add All",
    "",
    "",
    "",
    "",
    "",
    "",
    "Lis kaikki",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
  },
  { "Satellite-Table",
    "Satelliten-Tabelle",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
  },
  { "Cards connected with steerable dish",
    "Karten die mit der drehbaren Schssel verbunden sind",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
  },
  { "Satellites",
    "Satelliten",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
  },
  { "Positions",
    "Positionen",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
  },
  { NULL }
  };
